@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketActionCommon.pm - common file for several modules
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketActionCommon.pm,v 1.75 2012/02/03 18:23:12 cr Exp $
+# $Id: AgentTicketActionCommon.pm,v 1.81.2.3 2012/05/30 21:13:55 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -241,12 +241,12 @@ sub Run {
     # convert dynamic field values into a structure for ACLs
     my %DynamicFieldACLParameters;
     DYNAMICFIELD:
-    for my $DynamcField ( keys %DynamicFieldValues ) {
-        next DYNAMICFIELD if !$DynamcField;
-        next DYNAMICFIELD if !$DynamicFieldValues{$DynamcField};
+    for my $DynamicField ( keys %DynamicFieldValues ) {
+        next DYNAMICFIELD if !$DynamicField;
+        next DYNAMICFIELD if !$DynamicFieldValues{$DynamicField};
 
-        $DynamicFieldACLParameters{ 'DynamicField_' . $DynamcField }
-            = $DynamicFieldValues{$DynamcField};
+        $DynamicFieldACLParameters{ 'DynamicField_' . $DynamicField }
+            = $DynamicFieldValues{$DynamicField};
     }
     $GetParam{DynamicField} = \%DynamicFieldACLParameters;
 
@@ -600,7 +600,7 @@ sub Run {
         }
 
         # set new responsible
-        if ( $Self->{Config}->{Responsible} ) {
+        if ( $Self->{ConfigObject}->Get('Ticket::Responsible') && $Self->{Config}->{Responsible} ) {
             if ( $GetParam{NewResponsibleID} ) {
                 my $BodyText = $Self->{LayoutObject}->RichText2Ascii(
                     String => $GetParam{Body} || '',
@@ -790,12 +790,12 @@ sub Run {
         # convert dynamic field values into a structure for ACLs
         my %DynamicFieldACLParameters;
         DYNAMICFIELD:
-        for my $DynamcField ( keys %DynamicFieldValues ) {
-            next DYNAMICFIELD if !$DynamcField;
-            next DYNAMICFIELD if !$DynamicFieldValues{$DynamcField};
+        for my $DynamicField ( keys %DynamicFieldValues ) {
+            next DYNAMICFIELD if !$DynamicField;
+            next DYNAMICFIELD if !$DynamicFieldValues{$DynamicField};
 
-            $DynamicFieldACLParameters{ 'DynamicField_' . $DynamcField }
-                = $DynamicFieldValues{$DynamcField};
+            $DynamicFieldACLParameters{ 'DynamicField_' . $DynamicField }
+                = $DynamicFieldValues{$DynamicField};
         }
 
         # get list type
@@ -918,11 +918,12 @@ sub Run {
                     Max         => 100,
                 },
                 {
-                    Name        => 'NewPriorityID',
-                    Data        => $Priorities,
-                    SelectedID  => $GetParam{NewPriorityID},
-                    Translation => 1,
-                    Max         => 100,
+                    Name         => 'NewPriorityID',
+                    Data         => $Priorities,
+                    SelectedID   => $GetParam{NewPriorityID},
+                    PossibleNone => 0,
+                    Translation  => 1,
+                    Max          => 100,
                 },
                 {
                     Name         => 'ServiceID',
@@ -1097,7 +1098,7 @@ sub _Mask {
             Data  => \%Type,
             Name  => 'TypeID',
             SelectedID   => $Param{TypeID},
-            PossibleNone => 1,
+            PossibleNone => 0,
             Sort         => 'AlphanumericValue',
             Translation  => 0,
         );
@@ -1183,7 +1184,7 @@ sub _Mask {
             SelectedID => $Param{NewOwnerID},
             Name       => 'NewOwnerID',
             Class      => $Param{NewOwnerInvalid} || ' ',
-            Size       => 10,
+            Size       => 1,
 
         );
         my %UserHash;
@@ -1227,7 +1228,7 @@ sub _Mask {
             Data => \%Param,
         );
     }
-    if ( $Self->{Config}->{Responsible} ) {
+    if ( $Self->{ConfigObject}->Get('Ticket::Responsible') && $Self->{Config}->{Responsible} ) {
 
         # get user of own groups
         my %ShownUsers;
@@ -1256,7 +1257,7 @@ sub _Mask {
             Data       => \%ShownUsers,
             SelectedID => $Param{NewResponsibleID} || $Ticket{ResponsibleID},
             Name       => 'NewResponsibleID',
-            Size       => 10,
+            Size       => 1,
         );
         $Self->{LayoutObject}->Block(
             Name => 'Responsible',
@@ -1281,7 +1282,6 @@ sub _Mask {
         else {
             $State{SelectedID} = $Param{NewStateID};
         }
-        $State{SelectedID} ||= $Param{StateID};
 
         # build next states string
         $Param{StateStrg} = $Self->{LayoutObject}->BuildSelection(
@@ -1567,7 +1567,7 @@ sub _GetResponsible {
         my $GID = $Self->{QueueObject}->GetQueueGroupID( QueueID => $Param{QueueID} );
         my %MemberList = $Self->{GroupObject}->GroupMemberList(
             GroupID => $GID,
-            Type    => 'note',
+            Type    => 'responsible',
             Result  => 'HASH',
             Cached  => 1,
         );
@@ -1694,7 +1694,7 @@ sub _GetServices {
             $ServiceLoockup{ $ServiceData->{ServiceID} } = $ServiceData;
         }
 
-        # to store all ready printed ServiceIDs
+        # to store already printed ServiceIDs
         my %AddedServices;
 
         for my $ServiceKey ( sort { $OrigService{$a} cmp $OrigService{$b} } keys %OrigService ) {
